"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var perf_hooks_1 = require("perf_hooks");
/**
 * PerformanceTest
 */
var PerformanceTest = /** @class */ (function () {
    function PerformanceTest(testSubject) {
        this.testSubject = testSubject;
        this.iterations = 100;
        this.testResult = [];
    }
    PerformanceTest.prototype.run = function () {
        if (Array.isArray(this.testSubject)) {
            for (var i = 0; i < this.testSubject.length; i++) {
                this.testIterator(this.testSubject[i]);
            }
        }
        else {
            this.testIterator(this.testSubject);
        }
        return this.testResult;
    };
    PerformanceTest.prototype.testIterator = function (_a) {
        var fn = _a.fn, _b = _a.args, args = _b === void 0 ? [] : _b, _c = _a.options, options = _c === void 0 ? {} : _c;
        var durationArr = [], t0, t1;
        var lowestTime;
        var highestTime;
        var maxIterations = options.iterations || this.iterations;
        for (var i = 0; i < maxIterations; i++) {
            // run
            t0 = perf_hooks_1.performance.now();
            fn.apply(void 0, args);
            t1 = perf_hooks_1.performance.now();
            // calculate and store run time
            var runTime = +(t1 - t0);
            durationArr.push(runTime);
            // min run time
            if (!lowestTime || runTime < lowestTime) {
                lowestTime = this.toNumber(runTime);
            }
            // max run time
            if (!highestTime || runTime > highestTime) {
                highestTime = this.toNumber(runTime);
            }
        }
        // calculate average
        var durationsSum = durationArr.reduce(function (a, b) { return a + b; }, 0);
        var averageTime = this.toNumber(durationsSum / durationArr.length);
        this.testResult.push({
            functionName: fn.name,
            iterationsRun: maxIterations,
            averageTime: averageTime,
            lowestTime: lowestTime,
            highestTime: highestTime
        });
    };
    PerformanceTest.prototype.toNumber = function (num, digits) {
        if (digits === void 0) { digits = 4; }
        return +(num.toFixed(digits));
    };
    return PerformanceTest;
}());
exports.PerformanceTest = PerformanceTest;
exports.performanceTest = function (testSubject) { return new PerformanceTest(testSubject); };
